| Title: | Test Data for the 'admiral' Package |
|---|---|
| Description: | A set of Study Data Tabulation Model (SDTM) datasets from the Clinical Data Interchange Standards Consortium (CDISC) pilot project used for testing and developing Analysis Data Model (ADaM) derivations inside the 'admiral' package. |
| Authors: | Ben Straub [aut, cre], Stefan Bundfuss [aut], Gordon Miller [aut], Thomas Neitmann [aut], Syed Mubasheer [aut], Ross Farrugia [ctb], Shan Lee [ctb], Gopi Vegesna [ctb], Sophie Shapcott [ctb], Mahdi About [ctb], Antonio Rodríguez [ctb], Claudia Carlucci [ctb], Annie Yang [ctb], Tamara Senior [ctb], F. Hoffmann-La Roche AG [cph, fnd], GlaxoSmithKline LLC [cph, fnd], Clinical Data Interchange Standards Consortium [cph] |
| Maintainer: | Ben Straub <[email protected]> |
| License: | Apache License (>= 2.0) |
| Version: | 0.7.0 |
| Built: | 2026-05-31 10:08:53 UTC |
| Source: | https://github.com/cran/admiral.test |
An updated SDTM AE dataset that uses the CDISC pilot project
admiral_aeadmiral_ae
An object of class tbl_df (inherits from tbl, data.frame) with 1191 rows and 36 columns.
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_ae.rda
A SDTM CM dataset from the CDISC pilot project
admiral_cmadmiral_cm
An object of class tbl_df (inherits from tbl, data.frame) with 7510 rows and 21 columns.
A SDTM DM dataset from the CDISC pilot project
admiral_dmadmiral_dm
An object of class tbl_df (inherits from tbl, data.frame) with 306 rows and 25 columns.
An updated SDTM DS dataset that uses the CDISC pilot project
admiral_dsadmiral_ds
An object of class tbl_df (inherits from tbl, data.frame) with 850 rows and 13 columns.
Gopi Vegesna
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_ds.rda
An example of standard SDTM EG dataset to be used in deriving ADEG dataset
admiral_egadmiral_eg
An object of class tbl_df (inherits from tbl, data.frame) with 26669 rows and 24 columns.
A SDTM EX dataset from the CDISC pilot project
admiral_exadmiral_ex
An object of class tbl_df (inherits from tbl, data.frame) with 591 rows and 17 columns.
An updated SDTM LB dataset that uses data from the CDISC pilot project
admiral_lbadmiral_lb
An object of class tbl_df (inherits from tbl, data.frame) with 59580 rows and 23 columns.
Annie Yang
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_lb.rda
An updated SDTM MH dataset that uses data from the CDISC pilot project
admiral_mhadmiral_mh
An object of class tbl_df (inherits from tbl, data.frame) with 1818 rows and 28 columns.
Annie Yang
A SDTM OE dataset simulated by Ophthalmology team
admiral_oeadmiral_oe
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 15344 rows and 25 columns.
Gordon Miller
A SDTM PC dataset simulated by Antonio Rodríguez Contestí
admiral_pcadmiral_pc
An object of class tbl_df (inherits from tbl, data.frame) with 3556 rows and 20 columns.
Antonio Rodríguez Contestí
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_pc.rda
A SDTM PP dataset simulated by Antonio Rodríguez Contestí
admiral_ppadmiral_pp
An object of class data.frame with 2346 rows and 14 columns.
Antonio Rodríguez Contestí
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_pp.rda
A SDTM QS dataset from the CDISC pilot project & Ophthalmology test data
admiral_qsadmiral_qs
An object of class tbl_df (inherits from tbl, data.frame) with 202907 rows and 20 columns.
https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_qs.rda # nolint
A SDTM RS dataset simulated by Gopi Vegesna
admiral_rsadmiral_rs
An object of class tbl_df (inherits from tbl, data.frame) with 5808 rows and 19 columns.
Gopi Vegesna
A SDTM SC dataset simulated by Ophthalmology team
admiral_scadmiral_sc
An object of class tbl_df (inherits from tbl, data.frame) with 254 rows and 12 columns.
Gordon Miller
An example SDG dataset
admiral_sdg_dbadmiral_sdg_db
An object of class tbl_df (inherits from tbl, data.frame) with 16 rows and 5 columns.
An example SMQ dataset
admiral_smq_dbadmiral_smq_db
An object of class tbl_df (inherits from tbl, data.frame) with 44 rows and 6 columns.
A SDTM SUPPAE dataset from the CDISC pilot project
admiral_suppaeadmiral_suppae
An object of class tbl_df (inherits from tbl, data.frame) with 1191 rows and 10 columns.
A SDTM SUPPDM dataset from the CDISC pilot project
admiral_suppdmadmiral_suppdm
An object of class tbl_df (inherits from tbl, data.frame) with 1197 rows and 10 columns.
A SDTM SUPPDS dataset from the CDISC pilot project
admiral_suppdsadmiral_suppds
An object of class tbl_df (inherits from tbl, data.frame) with 3 rows and 9 columns.
A SDTM SUPPTR dataset simulated by Gopi Vegesna
admiral_supptradmiral_supptr
An object of class tbl_df (inherits from tbl, data.frame) with 55995 rows and 9 columns.
Gopi Vegesna
A SDTM SV dataset from the CDISC pilot project
admiral_svadmiral_sv
An object of class tbl_df (inherits from tbl, data.frame) with 3559 rows and 8 columns.
A SDTM TR dataset simulated by Gopi Vegesna
admiral_tradmiral_tr
An object of class tbl_df (inherits from tbl, data.frame) with 55995 rows and 24 columns.
Gopi Vegesna
A SDTM TS dataset from the CDISC pilot project
admiral_tsadmiral_ts
An object of class tbl_df (inherits from tbl, data.frame) with 33 rows and 6 columns.
A SDTM TU dataset simulated by Gopi Vegesna
admiral_tuadmiral_tu
An object of class tbl_df (inherits from tbl, data.frame) with 7734 rows and 18 columns.
Gopi Vegesna
A SDTM VS dataset from the CDISC pilot project
admiral_vsadmiral_vs
An object of class tbl_df (inherits from tbl, data.frame) with 29643 rows and 24 columns.
An example function as expected by the 'get_terms_fun' parameter of 'admiral::create_query_data()'
get_terms(basket_select, version, keep_id, temp_env)get_terms(basket_select, version, keep_id, temp_env)
basket_select |
A basket_select object defining the terms |
version |
MedDRA version |
keep_id |
Should 'GRPID' be included in the output? |
temp_env |
Temporary environment |
A SDTM AE dataset from the CDISC pilot project
raw_aeraw_ae
An object of class tbl_df (inherits from tbl, data.frame) with 1191 rows and 35 columns.
A SDTM DS dataset from the CDISC pilot project
raw_dsraw_ds
An object of class tbl_df (inherits from tbl, data.frame) with 596 rows and 13 columns.
A SDTM LB dataset from the CDISC pilot project
raw_lbraw_lb
An object of class tbl_df (inherits from tbl, data.frame) with 59580 rows and 23 columns.
A SDTM MH dataset from the CDISC pilot project
raw_mhraw_mh
An object of class tbl_df (inherits from tbl, data.frame) with 1818 rows and 19 columns.
A SDTM QS dataset from the CDISC pilot project
raw_qsraw_qs
An object of class tbl_df (inherits from tbl, data.frame) with 121749 rows and 20 columns.
A SDTM SUPPDS dataset from the CDISC pilot project
raw_suppdsraw_suppds
An object of class tbl_df (inherits from tbl, data.frame) with 3 rows and 10 columns.